@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 require XSLoader;
 XSLoader::load('Etk', $VERSION);
@@ -28,6 +28,53 @@ sub ModelAdd {
 	push @{$col->{_models}}, $model->{_model};
 }
 
+package Etk::Combobox;
+
+sub ItemAppend {
+	my $self = shift;
+	my $item = $self->ItemAppendEmpty();
+	$item->FieldsSet(@_) if @_;
+	return $item;
+}
+
+sub ItemPrepend {
+	my $self = shift;
+	my $item = $self->ItemPrependEmpty();
+	$item->FieldsSet(@_) if @_;
+	return $item;
+}
+
+sub ItemInsert {
+	my $self = shift;
+	my $after = shift;
+	my $item = $self->ItemInsert($after);
+	$item->FieldsSet(@_) if @_;
+	return $item;
+}
+
+package Etk::Combobox::Entry;
+
+sub ItemAppend {
+	my $self = shift;
+	my $item = $self->ItemAppendEmpty();
+	$item->FieldsSet(@_) if @_;
+	return $item;
+}
+
+sub ItemPrepend {
+	my $self = shift;
+	my $item = $self->ItemPrependEmpty();
+	$item->FieldsSet(@_) if @_;
+	return $item;
+}
+
+sub ItemInsert {
+	my $self = shift;
+	my $after = shift;
+	my $item = $self->ItemInsert($after);
+	$item->FieldsSet(@_) if @_;
+	return $item;
+}
 
 1;
 __END__
@@ -81,7 +128,7 @@ Hisham Mardam Bey, E<lt>hisham.mardambey@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007 by Chady Kassouf
+Copyright (C) 2008 by Chady Kassouf
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
